@@ -1,9 +1,9 @@
 import pytest
+import uuid
 
-from django_q.tasks import async
+from django_q.tasks import async_task
 from django_q.brokers import get_broker
 from django_q.cluster import Cluster
-from django_q.compat import range
 from django_q.monitor import monitor, info
 from django_q.status import Stat
 from django_q.conf import Conf
@@ -11,7 +11,8 @@ from django_q.conf import Conf
 
 @pytest.mark.django_db
 def test_monitor(monkeypatch):
-    assert Stat.get(0).sentinel == 0
+    cluster_id = uuid.uuid4()
+    assert Stat.get(pid=0, cluster_id=cluster_id).sentinel == 0
     c = Cluster()
     c.start()
     stats = monitor(run_once=True)
@@ -19,7 +20,7 @@ def test_monitor(monkeypatch):
     assert len(stats) > 0
     found_c = False
     for stat in stats:
-        if stat.cluster_id == c.pid:
+        if stat.cluster_id == c.cluster_id:
             found_c = True
             assert stat.uptime() > 0
             assert stat.empty_queues() is True
@@ -46,4 +47,4 @@ def test_info():
 
 
 def do_sync():
-    async('django_q.tests.tasks.countdown', 1, sync=True, save=True)
+    async_task('django_q.tests.tasks.countdown', 1, sync=True, save=True)
